@@ -1,21 +1,54 @@
-#include <R.h>
-#include "WELL512a.h"
-#include "WELL521a.h"
-#include "WELL521b.h"
-#include "WELL607a.h"
-#include "WELL607b.h"
-#include "WELL800a.h"
-#include "WELL800b.h"
-#include "WELL1024a.h"
-#include "WELL1024b.h"
-#include "WELL19937a.h"
-#include "WELL19937c.h"
-#include "WELL19937b.h"
-#include "WELL21701a.h"
-#include "WELL23209a.h"
-#include "WELL23209b.h"
-#include "WELL44497a.h"
-#include "WELL44497b.h"
+/** 
+ * @file  runifInterface.c
+ * @brief C file for 'runif' interface
+ *
+ * @author Petr Savicky 
+ *
+ *
+ * Copyright (C) 2009, Petr Savicky, Academy of Sciences of the Czech Republic. 
+ * All rights reserved.
+ *
+ * The new BSD License is applied to this software.
+ * Copyright (c) 2009 Petr Savicky, Academy of Sciences of the Czech Republic. 
+ * All rights reserved.
+ *
+ *      Redistribution and use in source and binary forms, with or without
+ *      modification, are permitted provided that the following conditions are
+ *      met:
+ *      
+ *          - Redistributions of source code must retain the above copyright
+ *          notice, this list of conditions and the following disclaimer.
+ *          - Redistributions in binary form must reproduce the above
+ *          copyright notice, this list of conditions and the following
+ *          disclaimer in the documentation and/or other materials provided
+ *          with the distribution.
+ *          - Neither the name of the Academy of Sciences of the Czech Republic
+ *          nor the names of its contributors may be used to endorse or promote 
+ *          products derived from this software without specific prior written
+ *          permission.
+ *     
+ *      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ *      "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ *      LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ *      A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ *      OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ *      SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ *      LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *      DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ *      THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ *      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ *      OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *  
+ */
+/*****************************************************************************
+ *  runif interface
+ *    
+ *      C file
+ *
+ */
+
+#include "runifInterface.h"
+
 
 typedef void(*UserUnifSetGeneratorType)(int gener, void (*selected_init)(unsigned int), double (*selected_rand)());
 
@@ -254,6 +287,7 @@ void putRngWELL512(unsigned int *state)
 		InitWELLRNG512a( state );
 		user_unif_set_generator(2, seedWELLRNG512a, generateWELLRNG512a);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -269,6 +303,7 @@ void putRngWELL521(unsigned int *state)
 		InitWELLRNG521b( state );
 		user_unif_set_generator(2, seedWELLRNG521b, generateWELLRNG521b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -284,6 +319,7 @@ void putRngWELL607(unsigned int *state)
 		InitWELLRNG607b( state );
 		user_unif_set_generator(2, seedWELLRNG607b, generateWELLRNG607b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -299,6 +335,7 @@ void putRngWELL800(unsigned int *state)
 		InitWELLRNG800b( state );
 		user_unif_set_generator(2, seedWELLRNG800b, generateWELLRNG800b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -314,6 +351,7 @@ void putRngWELL1024(unsigned int *state)
 		InitWELLRNG1024b( state );
 		user_unif_set_generator(2, seedWELLRNG1024b, generateWELLRNG1024b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -333,6 +371,7 @@ void putRngWELL19937(unsigned int *state)
 		InitWELLRNG19937c( state );
 		user_unif_set_generator(2, seedWELLRNG19937c, generateWELLRNG19937c);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));		
 	}
 }
 
@@ -344,6 +383,7 @@ void putRngWELL21701(unsigned int *state)
 		InitWELLRNG21701a( state );
 		user_unif_set_generator(2, seedWELLRNG21701a, generateWELLRNG21701a);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));									
 	}
 }
 
@@ -359,6 +399,7 @@ void putRngWELL23209(unsigned int *state)
 		InitWELLRNG23209b( state );
 		user_unif_set_generator(2, seedWELLRNG23209b, generateWELLRNG23209b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));									
 	}
 }
 
@@ -374,6 +415,7 @@ void putRngWELL44497(unsigned int *state)
 		InitWELLRNG44497b( state );
 		user_unif_set_generator(2, seedWELLRNG44497b, generateWELLRNG44497b);
 		break;
+	//default: error(_("wrong version in putRngWELLXXX"));						
 	}
 }
 
@@ -392,6 +434,7 @@ void putRngWELL(int *porder, int *pversion, unsigned int *state)
 		case 21701: putRngWELL21701(state); break;
 		case 23209: putRngWELL23209(state); break;
 		case 44497: putRngWELL44497(state); break;
+        //default: error(_("wrong order in putRngWELL"));			
 	}
 }
 
@@ -403,6 +446,7 @@ void getRngWELL512(unsigned int *state)
 	{
 	case 1:
 		GetWELLRNG512a( state );
+	//default: error(_("wrong version in getRngWELLXXX"));		
 	}
 }
 
@@ -415,6 +459,7 @@ void getRngWELL521(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG521b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -427,6 +472,7 @@ void getRngWELL607(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG607b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -439,6 +485,7 @@ void getRngWELL800(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG800b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -451,6 +498,7 @@ void getRngWELL1024(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG1024b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -466,6 +514,7 @@ void getRngWELL19937(unsigned int *state)
 		break;
 	case 3:
 		GetWELLRNG19937c( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -475,6 +524,7 @@ void getRngWELL21701(unsigned int *state)
 	{
 	case 1:
 		GetWELLRNG21701a( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -487,6 +537,7 @@ void getRngWELL23209(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG23209b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -499,6 +550,7 @@ void getRngWELL44497(unsigned int *state)
 		break;
 	case 2:
 		GetWELLRNG44497b( state );
+	//default: error(_("wrong version in getRngWELLXXX"));			
 	}
 }
 
@@ -517,6 +569,7 @@ void getRngWELL(int *porder, int *pversion, unsigned int *state)
 		case 21701: getRngWELL21701(state); break;
 		case 23209: getRngWELL23209(state); break;
 		case 44497: getRngWELL44497(state); break;
+		//default: error(_("wrong order in getRngWELL"));		
 	}
 }
 
